/*jshint node:true*/

var gruntHelper = module.exports,
	grunt = require('grunt'),
	_ = require('underscore');


var Clean = require('./gruntHelpers/clean.js');
var Concat = require('./gruntHelpers/concat.js');
var Pure_grids = require('./gruntHelpers/pure_grids.js');
var Handlebars = require('./gruntHelpers/handlebars.js');
var Copy = require('./gruntHelpers/copy.js');
var Browserify = require('./gruntHelpers/browserify.js');


function getFullConfig() {

	var full = {};
	_.each(['clean', 'concat', 'pure_grids', 'handlebars', 'copy', 'browserify'], function(key) {
		if (_.size(gruntHelper[key].config) > 0) {
			full[key] = gruntHelper[key].config;
		}
	});

	return full;

}

gruntHelper.runTasks = function(taskList) {

	grunt.loadNpmTasks('grunt-contrib-clean');
	grunt.loadNpmTasks('grunt-contrib-concat');
	grunt.loadNpmTasks('grunt-contrib-copy');
	grunt.loadNpmTasks('grunt-pure-grids');
	grunt.loadNpmTasks('grunt-contrib-handlebars');
	grunt.loadNpmTasks('grunt-browserify');

	var gruntConfig = getFullConfig();

	if (process.env.NODE_ENV === 'test') {
		console.log('gruntConfig ->');
		console.log(JSON.stringify(gruntConfig, null, 4));
	}

	grunt.initConfig(gruntConfig);



	grunt.task.run(taskList);
	grunt.task.start();

};


gruntHelper.reset = function() {

	gruntHelper.clean = new Clean();
	gruntHelper.concat = new Concat();
	gruntHelper.pure_grids = new Pure_grids();
	gruntHelper.handlebars = new Handlebars();
	gruntHelper.copy = new Copy();
	gruntHelper.browserify = new Browserify();

};




gruntHelper.reset();

// expose private functions for testing
if (process.env.NODE_ENV === 'test') {
	gruntHelper._private = {
		getFullConfig: getFullConfig
	};
}
