/*jshint node:true*/
var _ = require('underscore'),
	gruntHelper = require('./gruntHelper.js'),
	componentBuilder = require('./componentBuilder.js'),
	fs = require('fs');

module.exports = {

	init: function(conf) {

		this.conf = conf;
		var taskList = [];

		// grid
		if (conf.build.grid) {

			gruntHelper.pure_grids.init(conf.build.grid, conf.output.css.components);
			taskList.push('pure_grids');

			// replace __grid__ in build.css.base
			conf.build.css.base = gruntHelper.pure_grids.insertGridPaths(conf.build.css.base, conf.output.css.components);

		}

		// base css
		gruntHelper.clean.add('basecss', this.getOutputPath('css', 'base'));
		taskList.push('clean:basecss');
		gruntHelper.concat.add('basecss', this.getOutputPath('css', 'base'), conf.build.css.base);
		taskList.push('concat:basecss');

		// components css/js
		gruntHelper.clean.add('components', this.getOutputPath('css', 'components'));
		taskList.push('clean:components');

		componentBuilder.init(conf);
		componentBuilder.createTasks(gruntHelper, 'components', taskList);
		taskList.push('concat:components');




		// components JST
		gruntHelper.handlebars.init(conf);
		gruntHelper.handlebars.add('styleguide_components', conf.output.jst + '/_all_components.js', [conf.sources.components + '/**/*.hbs'], {partials: true});
		taskList.push('handlebars:styleguide_components');


		// concat all handlebars_helpers for styleguide
		gruntHelper.concat.add('styleguide_hbs_helpers', conf.output.js + '/handlebars-helpers.js', conf.sources.handlebars_helpers + '/*.js');
		taskList.push('concat:styleguide_hbs_helpers');


		// cleanup all temp files
		gruntHelper.clean.add('tempfiles', [
			conf.output.css.base + '/__*.css',
			conf.output.css.components + '/__*.css',
			conf.output.css.themes + '/__*.css'
		]);
		taskList.push('clean:tempfiles');


		gruntHelper.runTasks(taskList);

	},

	addToGruntConcat: function(taskName, target, sources) {

		var files = {};
		files[target] = sources;

	},

	getOutputPath: function(type, name) {
		return this.conf.output[type][name] + '/' + name + '.css';
	}
};
